package main

import "fmt"

type Profile struct {
	Name     string
	Date     string  // for now it's a string (TODO date.go)
	Location string  // for now it's a string (TODO location.go)
	Playtime float64 // Play time in seconds
	// TODO travel.go
}

func (p *Profile) Parse(node *Node) error {
	if node.Tag != "root" {
		return fmt.Errorf("non-root node given, expected root node")
	}
	for _, kid := range node.Children {
		switch kid.Key() {
		case "pilot":
			p.Name = kid.Value()
		case "data":
			p.Date = kid.Value()
		case "system":
			p.Location = kid.Value()
		case "planet":
			if p.Location != "" {
				p.Location += ", "
			}
			p.Location += kid.Value()
		case "playtime":
			p.Playtime = kid.ValueFloat64()
		}
	}
	return nil
}

func (p *Profile) Update(node *Node) error {
	if node.Tag != "root" {
		return fmt.Errorf("non-root node given, expected root node")
	}
	for _, kid := range node.Children {
		switch kid.Key() {
		case "pilot":
			kid.SetValue(p.Name)
		case "date":
			kid.SetValue(p.Date)
		case "playtime":
			kid.SetValue(p.Playtime)
		}
	}
	return nil
}

func (p *Profile) Type() string {
	return "Profile"
}
